==> droptopus-0.2.39.tar.gz: droptopus-0.2.39/README.md <==
[![Build Status][build-status-src]][build-status-href]
[![GitHub stars][github-stars-src]][github-stars-href]
[![GitHub license][github-license-src]][github-license-href]
[![GitHub issues][github-issues-src]][github-issues-href]

# Droptopus
![Droptopus Logo][droptopus-logo-src]

Droptopus allows you to create visual drop targets for files, links, and text, allowing you to process the dragged object via script or copy it to a folder.

<img src="https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-collapsed.png?v=2" width="auto" height="100" />
<img src="https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-expanded.png?v=2" width="auto" height="100" />
<img src="https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-right-click.png?v=2" width="auto" height="100" />


# Dependencies 
 - python3.5+
 - pyqt5

# Installation
 `pip3 install droptopus`

# Launch
 `python3 -m droptopus &`

# Example scripts
  Check the [examples][examples-href] directory for some useful drop actions.

## Acknowledgements

Droptopus uses

- [Nokia's][nokia-href]: [Qt][qt-href]

- [Riverbank Computing Limited's][riverbank-href]: [SIP][sip-href]

- [Riverbank Computing Limited's][riverbank-href]: [PyQt5][pyqt-href]

- [Icon8's][icons8-href]: [awesome icons][icons8-href]

Thanks!

## Sponsors

[![Become a sponsor][patreon-src]][patreon-href]

## License

This project is licensed under the MIT License - see the [LICENSE.md][github-license-href] file for details

[droptopus-logo-src]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/droptopus/assets/droptopus.png
[build-status-href]: https://travis-ci.org/ArtBIT/droptopus
[build-status-src]: https://travis-ci.org/ArtBIT/droptopus.svg
[github-issues-href]: https://github.com/ArtBIT/droptopus/issues
[github-issues-src]: https://img.shields.io/github/issues/ArtBIT/droptopus.svg
[github-license-href]: https://github.com/ArtBIT/Droptopus/blob/master/LICENSE.md
[github-license-src]: https://img.shields.io/github/license/ArtBIT/droptopus.svg
[github-stars-href]: https://github.com/ArtBIT/droptopus
[github-stars-src]: https://img.shields.io/github/stars/ArtBIT/droptopus.svg
[icons8-href]: http://icons8.com
[nokia-href]: http://www.nokia.com
[pyqt-href]: http://www.riverbankcomputing.co.uk/software/pyqt/intro
[qt-href]: http://qt.nokia.com
[riverbank-href]: http://www.riverbankcomputing.co.uk
[sip-href]: http://www.riverbankcomputing.co.uk/software/sip/intro
[patreon-src]: https://img.shields.io/badge/Patreon-Sponsor%20This-orange.svg
[patreon-href]: https://www.patreon.com/artbit
[examples-href]: https://github.com/ArtBIT/Droptopus/tree/master/examples
[droptopus-screenshot-1]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-collapsed.png
[droptopus-screenshot-2]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-expanded.png
[droptopus-screenshot-3]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-right-click.png

==> droptopus-0.2.47.tar.gz: droptopus-0.2.47/README.md <==
[![GitHub stars][github-stars-src]][github-stars-href]
[![GitHub license][github-license-src]][github-license-href]
[![GitHub issues][github-issues-src]][github-issues-href]

# Droptopus
![Droptopus Logo][droptopus-logo-src]

Droptopus melds drag'n'drop with scripts and folders. It allows you to create visual drop targets for files, links, and text, allowing you to process the dragged object (file|text|url) via script or copy it to a folder.

<img src="https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-collapsed.png?v=2" width="auto" height="100" />
<img src="https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-expanded.png?v=2" width="auto" height="100" />
<img src="https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-right-click.png?v=2" width="auto" height="100" />


# Dependencies 
 - python3.5+
 - pyqt5

# Installation
 `pip3 install droptopus`

# Launch
 `nohup python3 -m droptopus &`

# Example scripts
  Check the [examples][examples-href] directory for some useful drop actions.

## Acknowledgements

Droptopus uses

- [Nokia's][nokia-href]: [Qt][qt-href]

- [Riverbank Computing Limited's][riverbank-href]: [SIP][sip-href]

- [Riverbank Computing Limited's][riverbank-href]: [PyQt5][pyqt-href]

- [Icon8's][icons8-href]: [awesome icons][icons8-href]

Thanks!

## Sponsors

[![Become a sponsor][patreon-src]][patreon-href]

## License

This project is licensed under the MIT License - see the [LICENSE.md][github-license-href] file for details

[droptopus-logo-src]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/droptopus/assets/droptopus.png
[github-issues-href]: https://github.com/ArtBIT/droptopus/issues
[github-issues-src]: https://img.shields.io/github/issues/ArtBIT/droptopus.svg
[github-license-href]: https://github.com/ArtBIT/Droptopus/blob/master/LICENSE.md
[github-license-src]: https://img.shields.io/github/license/ArtBIT/droptopus.svg
[github-stars-href]: https://github.com/ArtBIT/droptopus
[github-stars-src]: https://img.shields.io/github/stars/ArtBIT/droptopus.svg
[icons8-href]: http://icons8.com
[nokia-href]: http://www.nokia.com
[pyqt-href]: http://www.riverbankcomputing.co.uk/software/pyqt/intro
[qt-href]: http://qt.nokia.com
[riverbank-href]: http://www.riverbankcomputing.co.uk
[sip-href]: http://www.riverbankcomputing.co.uk/software/sip/intro
[patreon-src]: https://img.shields.io/badge/Patreon-Sponsor%20This-orange.svg
[patreon-href]: https://www.patreon.com/artbit
[examples-href]: https://github.com/ArtBIT/Droptopus/tree/master/examples
[droptopus-screenshot-1]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-collapsed.png
[droptopus-screenshot-2]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-expanded.png
[droptopus-screenshot-3]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/images/droptopus-right-click.png
